#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class FittingSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         FittingSettingAtt
                | 
                | Interface to handle parameters of DMU Fitting Tools Options Tab page Role: This
                | interface is implemented by a component which represents the controller of DMU
                | Fitting Tools Options parameter settings.
                | 
                |     Methods to set value of each parameter
                |     Methods to get value of each parameter
                |     Methods to get information on each parameter
                |     Methods to lock/unlock value of each parameter
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.fitting_setting_att = com_object

    def get_angle_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAngleLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the AngleLimit
                |     parameter.
                |     Role:Retrieves the state of the AngleLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fitting_setting_att.GetAngleLimitInfo(io_admin_level, io_locked)

    def get_clash_while_moving_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetClashWhileMovingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the AskAnlMode
                |     parameter.
                |     Role:Retrieves the state of the AskAnlMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fitting_setting_att.GetClashWhileMovingInfo(io_admin_level, io_locked)

    def get_default_speed_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDefaultSpeedInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the DefaultSpeed
                |     parameter.
                |     Role:Retrieves the state of the DefaultSpeed parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fitting_setting_att.GetDefaultSpeedInfo(io_admin_level, io_locked)

    def get_default_time_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDefaultTimeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the DefaultTime
                |     parameter.
                |     Role:Retrieves the state of the DefaultTime parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fitting_setting_att.GetDefaultTimeInfo(io_admin_level, io_locked)

    def get_max_angle_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMaxAngleInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the MaxAngle
                |     parameter.
                |     Role:Retrieves the state of the MaxAngle parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fitting_setting_att.GetMaxAngleInfo(io_admin_level, io_locked)

    def get_path_finder_smooth_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPathFinderSmoothInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the PathFinderSmooth
                |     parameter.
                |     Role:Retrieves the state of the PathFinderSmooth parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fitting_setting_att.GetPathFinderSmoothInfo(io_admin_level, io_locked)

    def get_track_auto_update_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTrackAutoUpdateInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the TrackAutoUpdate
                |     parameter.
                |     Role:Retrieves the state of the TrackAutoUpdate parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fitting_setting_att.GetTrackAutoUpdateInfo(io_admin_level, io_locked)

    def get_vector_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVectorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the VisualizationMode
                |     parameter.
                |     Role:Retrieves the state of the VisualizationMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fitting_setting_att.GetVectorInfo(io_admin_level, io_locked)

    def set_angle_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAngleLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AngleLimit parameter.
                |     Role:Locks or unlocks the AngleLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fitting_setting_att.SetAngleLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_angle_limit_lock'
        # # vba_code = """
        # # Public Function set_angle_limit_lock(fitting_setting_att)
        # #     Dim iLocked (2)
        # #     fitting_setting_att.SetAngleLimitLock iLocked
        # #     set_angle_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_clash_while_moving_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetClashWhileMovingLock(boolean iLocked)
                | 
                |     Locks or unlocks the ClashWhileMoving parameter.
                |     Role:Locks or unlocks the ClashWhileMoving parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fitting_setting_att.SetClashWhileMovingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_clash_while_moving_lock'
        # # vba_code = """
        # # Public Function set_clash_while_moving_lock(fitting_setting_att)
        # #     Dim iLocked (2)
        # #     fitting_setting_att.SetClashWhileMovingLock iLocked
        # #     set_clash_while_moving_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_speed_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDefaultSpeedLock(boolean iLocked)
                | 
                |     Locks or unlocks the DefaultSpeed parameter.
                |     Role:Locks or unlocks the DefaultSpeed parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fitting_setting_att.SetDefaultSpeedLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_speed_lock'
        # # vba_code = """
        # # Public Function set_default_speed_lock(fitting_setting_att)
        # #     Dim iLocked (2)
        # #     fitting_setting_att.SetDefaultSpeedLock iLocked
        # #     set_default_speed_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_time_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDefaultTimeLock(boolean iLocked)
                | 
                |     Locks or unlocks the DefaultTime parameter.
                |     Role:Locks or unlocks the DefaultTime parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fitting_setting_att.SetDefaultTimeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_time_lock'
        # # vba_code = """
        # # Public Function set_default_time_lock(fitting_setting_att)
        # #     Dim iLocked (2)
        # #     fitting_setting_att.SetDefaultTimeLock iLocked
        # #     set_default_time_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_max_angle_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMaxAngleLock(boolean iLocked)
                | 
                |     Locks or unlocks the MaxAngle parameter.
                |     Role:Locks or unlocks the MaxAngle parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fitting_setting_att.SetMaxAngleLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_max_angle_lock'
        # # vba_code = """
        # # Public Function set_max_angle_lock(fitting_setting_att)
        # #     Dim iLocked (2)
        # #     fitting_setting_att.SetMaxAngleLock iLocked
        # #     set_max_angle_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_path_finder_smooth_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPathFinderSmoothLock(boolean iLocked)
                | 
                |     Locks or unlocks the PathFinderSmooth parameter.
                |     Role:Locks or unlocks the PathFinderSmooth parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fitting_setting_att.SetPathFinderSmoothLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_path_finder_smooth_lock'
        # # vba_code = """
        # # Public Function set_path_finder_smooth_lock(fitting_setting_att)
        # #     Dim iLocked (2)
        # #     fitting_setting_att.SetPathFinderSmoothLock iLocked
        # #     set_path_finder_smooth_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_track_auto_update_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTrackAutoUpdateLock(boolean iLocked)
                | 
                |     Locks or unlocks the TrackAutoUpdate parameter.
                |     Role:Locks or unlocks the TrackAutoUpdate parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fitting_setting_att.SetTrackAutoUpdateLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_track_auto_update_lock'
        # # vba_code = """
        # # Public Function set_track_auto_update_lock(fitting_setting_att)
        # #     Dim iLocked (2)
        # #     fitting_setting_att.SetTrackAutoUpdateLock iLocked
        # #     set_track_auto_update_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_vector_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVectorLock(boolean iLocked)
                | 
                |     Locks or unlocks the VisualizationMode parameter.
                |     Role:Locks or unlocks the VisualizationMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fitting_setting_att.SetVectorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_vector_lock'
        # # vba_code = """
        # # Public Function set_vector_lock(fitting_setting_att)
        # #     Dim iLocked (2)
        # #     fitting_setting_att.SetVectorLock iLocked
        # #     set_vector_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'FittingSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameters import Parameters
from pycatia.knowledge_interfaces.relations import Relations
from pycatia.drafting_2dL_interfaces.layout_2d_sheet import Layout2DSheet
from pycatia.drafting_2dL_interfaces.layout_2d_sheets import Layout2DSheets
from pycatia.system_interfaces.any_object import AnyObject


class Layout2DRoot(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Layout2DRoot
                | 
                | Interface to manage the 2D Layout root.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.layout_2d_root = com_object

    @property
    def active_sheet(self) -> Layout2DSheet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveSheet() As Layout2DSheet
                | 
                |     Retrieves or sets the active sheet of the layout.
                | 
                |     Example:
                |         This example retrieves the active sheet currently managed by the layout
                |         root of a part of the active document, supposed to be a part
                |         document.
                | 
                |          Dim MyRoot As Layout2DRoot
                |          Set MyRoot = CATIA.ActiveDocument.Part.GetItem("CATLayout2DRoot)"
                |          Dim MySheet = MyRoot.GetActiveSheet

        :rtype: Layout2DSheet
        """

        return Layout2DSheet(self.layout_2d_root.ActiveSheet)

    @active_sheet.setter
    def active_sheet(self, value: Layout2DSheet):
        """
        :param Layout2DSheet value:
        """

        self.layout_2d_root.ActiveSheet = value

    @property
    def parameters(self) -> Parameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Parameters() As Parameters (Read Only)
                | 
                |     Returns the collection of parameters of the layout.
                | 
                |     Example:
                | 
                |           This example retrieves in layoutParameters the collection
                |           of
                |          parameters currently managed by the layout root of a part of the
                |          active document, 
                |          supposed to be a part document.
                |          
                | 
                |          Dim MyRoot As Layout2DRoot
                |          Set MyRoot = CATIA.ActiveDocument.Part.GetItem("CATLayout2DRoot)"
                |          Dim layoutParameters As Parameters
                |          Set layoutParameters = MyRoot.Parameters

        :rtype: Parameters
        """

        return Parameters(self.layout_2d_root.Parameters)

    @property
    def relations(self) -> Relations:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Relations() As Relations (Read Only)
                | 
                |     Returns the collection of relations of the part document.
                | 
                |     Example:
                | 
                |           This example retrieves in layoutRelations the collection
                |           of
                |          relations currently managed by the layout root of a part of the active
                |          document, 
                |          supposed to be a part document.
                |          
                | 
                |          Dim MyRoot As Layout2DRoot
                |          Set MyRoot = CATIA.ActiveDocument.Part.GetItem("CATLayout2DRoot)"
                |          Dim layoutRelations As Relations
                |          Set layoutRelations = MyRoot.Relations

        :rtype: Relations
        """

        return Relations(self.layout_2d_root.Relations)

    @property
    def rendering_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RenderingMode() As CatRenderingMode
                | 
                |     Set/Get the rendering mode of Layout2D. get_RenderingMode method can fail
                |     if rendering value stored on Layout is not a value defined in CatRenderingMode
                |     enum.
                | 
                |     Example:
                |         This example sets the rendering mode to catRenderShadingWithEdges for
                |         the layout root of a part of the active document.
                | 
                |          Dim MyRoot As Layout2DRoot
                |          Set MyRoot = CATIA.ActiveDocument.Part.GetItem("CATLayout2DRoot)"
                |          MyRoot. RenderingMode  = catRenderShadingWithEdges

        :return: enum cat_rendering_mode
        :rtype: int
        """

        return self.layout_2d_root.RenderingMode

    @rendering_mode.setter
    def rendering_mode(self, value: int):
        """
        :param int value: enum cat_rendering_mode
        """

        self.layout_2d_root.RenderingMode = value

    @property
    def sheets(self) -> Layout2DSheets:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Sheets() As Layout2DSheets (Read Only)
                | 
                |     Returns the collection of Layout2D sheets of the part
                |     document.
                | 
                |     Example:
                |         This example retrieves in SheetCollection the collection of sheets
                |         currently managed by the layout root of a part of the active document, supposed
                |         to be a part document.
                | 
                |          Dim MyRoot As Layout2DRoot
                |          Set MyRoot = CATIA.ActiveDocument.Part.GetItem("CATLayout2DRoot)"
                |          Dim SheetCollection As Layout2DSheets
                |          Set SheetCollection = MyRoot.Sheets.

        :rtype: Layout2DSheets
        """

        return Layout2DSheets(self.layout_2d_root.Sheets)

    @property
    def standard(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Standard() As CatDrawingStandard
                | 
                |     Returns or sets the DrawingStandard of the part document.
                | 
                |     Example:
                |         This example sets the drawing standard currently managed by the layout
                |         root of a part of the active document, supposed to be a part document, to
                |         ISO.
                | 
                |          Dim MyRoot As Layout2DRoot
                |          Set MyRoot = CATIA.ActiveDocument.Part.GetItem("CATLayout2DRoot)"
                |          MyRoot.Standard = catISO

        :return: enum cat_drawing_standard
        :rtype: int
        """

        return self.layout_2d_root.Standard

    @standard.setter
    def standard(self, value: int):
        """
        :param int value: enum cat_drawing_standard
        """

        self.layout_2d_root.Standard = value

    @property
    def visu_in_3d(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisuIn3D() As CatVisuIn3DMode
                | 
                |     Set/Get the 3D visualization mode of the layout in the 3D Viewer ie in the
                |     3D windows and in the background of each view in every 2D
                |     context.
                | 
                |     See also:
                |         CatVisuIn3DMode

        :return: enum cat_visu_in_3d_mode
        :rtype: int
        """

        return self.layout_2d_root.VisuIn3D

    @visu_in_3d.setter
    def visu_in_3d(self, value: int):
        """
        :param int value: enum cat_visu_in_3d_mode
        """

        self.layout_2d_root.VisuIn3D = value

    def reorder_sheets(self, i_ordered_sheets: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub reorder_Sheets(CATSafeArrayVariant iOrderedSheets)
                | 
                |     Changes the positions of the sheets in this drawing according to the given
                |     ordered list. iOrderedSheets is the result of a permutation applied to the list
                |     of all the sheets of this drawing, with the following constraint: For every
                |     non-detail sheet, there is not any detail sheet appearing before in
                |     iOrderedSheets.
                | 
                |     Example:
                |         This example inverts the sheet order of a drawing made of exactly two
                |         regular sheets.
                | 
                |          Set drwsheetsorder =  CATIA.ActiveDocument.Part.GetItem("CATLayoutRoot")
                |          Set drwsheets = drwsheetsorder.Sheets
                |          Set sheet1 = drwsheets.item(1)
                |          Set sheet2 = drwsheets.item(2)
                |          newsheetorder = Array(sheet2, sheet1)
                |          drwsheetsorder.reorder_Sheets(newsheetorder)

        :param tuple i_ordered_sheets:
        :rtype: None
        """
        return self.layout_2d_root.reorder_Sheets(i_ordered_sheets)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reorder_sheets'
        # # vba_code = """
        # # Public Function reorder_sheets(layout2_d_root)
        # #     Dim iOrderedSheets (2)
        # #     layout2_d_root.reorder_Sheets iOrderedSheets
        # #     reorder_sheets = iOrderedSheets
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Layout2DRoot(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connector import SchAppConnector
from pycatia.cat_sch_platform_interfaces.sch_grr import SchGRR
from pycatia.cat_sch_platform_interfaces.sch_grr_comp import SchGRRComp
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchCompatible(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchCompatible
                | 
                | Provides connecting rule to schematic objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_compatible = com_object

    def get_best_cntr_for_route(
            self,
            i_db2_placement_pt: tuple,
            i_grr: SchGRR,
            i_lok_cntrs: SchListOfObjects,
            o_db2_cntr_pt: SchListOfDoubles,
            o_best_cntr: SchAppConnector
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetBestCntrForRoute(CATSafeArrayVariant
                | iDb2PlacementPt,
                | SchGRR iGRR,
                | SchListOfObjects iLOKCntrs,
                | SchListOfDoubles oDb2CntrPt,
                | SchAppConnector oBestCntr)
                | 
                |     Find the best-fit connector to be used to connect a route
                |     to.
                | 
                |     Parameters:
                | 
                |         iDb2PlacementPt
                |             X-Y coordinates of the target (component or route) graphic
                |             selection point. 
                |         iGRR
                |             Pointer to the graphical image of a component or to the primitive
                |             of a route 
                |         iLOKCntrs
                |             A list of compatible and available connectors on the component.
                |             Members are CATISchAppConnector interface pointers. This is an Output of
                |             IsTargetOKForRoute 
                |         oDb2CntrPt
                |             X-Y coordinates of the best-fit connector point. 
                |         oBestCntr
                |             Best-fit connector 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchCompatible
                |          Dim dbVar1(2) As CATSafeArrayVariant
                |          Dim objArg2 As SchGRR
                |          Dim objArg3 As SchListOfObjects
                |          Dim objArg4 As SchListOfDoubles
                |          Dim objArg5 As SchAppConnector
                |           ...
                |          objThisIntf.GetBestCntrForRoutedbVar1,objArg2,objArg3,objArg4,objArg5

        :param tuple i_db2_placement_pt:
        :param SchGRR i_grr:
        :param SchListOfObjects i_lok_cntrs:
        :param SchListOfDoubles o_db2_cntr_pt:
        :param SchAppConnector o_best_cntr:
        :rtype: tuple
        """
        return self.sch_compatible.GetBestCntrForRoute(
            i_db2_placement_pt,
            i_grr.com_object,
            i_lok_cntrs.com_object,
            o_db2_cntr_pt.com_object,
            o_best_cntr.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_best_cntr_for_route'
        # # vba_code = """
        # # Public Function get_best_cntr_for_route(sch_compatible)
        # #     Dim iDb2PlacementPt (2)
        # #     sch_compatible.GetBestCntrForRoute iDb2PlacementPt
        # #     get_best_cntr_for_route = iDb2PlacementPt
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_best_fit_insert_info(
            self,
            i_db2_placement_pt: tuple,
            i_insert_compat_info: AnyObject,
            io_insert_info: AnyObject,
            i_b_yes_cycle_all_solns: bool
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetBestFitInsertInfo(CATSafeArrayVariant
                | iDb2PlacementPt,
                | AnyObject iInsertCompatInfo,
                | AnyObject ioInsertInfo,
                | boolean iBYesCycleAllSolns)
                | 
                |     Find the best-fit connector(s) to be used for inserting a component into a
                |     route.
                | 
                |     Parameters:
                | 
                |         iDb2PlacementPt
                |             X-Y coordinates of the target component graphical selection point.
                |             
                |         iInsertCompatInfo
                |             Pointer to an internal class which contains structured information
                |             This is an output of IsTargetOKForInsert 
                |         ioInsertInfo
                |             Pointer to an internal class which contains structured information
                |             for how to inesrt a component into a route. Caller must initialize this pointer
                |             to NULL when calling this code the first time. This is used as an input to
                |             CATISchComponent::InsertIntoRouteWithInfo 
                |         iBYesCycleAllSolns
                |             default is FALSE, and ioInsertInfo is an output for the best fit
                |             solution. When there are more than one internal flows that can be used for
                |             insertion, this routine will choose the best solution in the following
                |             order:
                | 
                |                 linear internal flow parallel to x-axis 
                |                 linear internal flow parallel to y-axis 
                |                 corner internal flow 
                |                 others 
                | 
                |             If iBYesCycleAllSolns =TRUE, then the implementation will calculate
                |             all possible solutions and allow the caller to recall this code with the same
                |             ioInsertInfo. if and only if current input iDB2PlacementPt is the the same as
                |             the previous one . Otherwise, the insertion position of the component on the
                |             route is different and the previously calculated solutions are all invalid for
                |             the current call. If the iDB2PlacementPt is the same as the previous one and
                |             iBYesCycleAllSolns is TRUE, this code will set the internal data ioInsertInfo
                |             accordingly, so that when used in InsertIntoRouteWithInfo, the next solution
                |             will be used. For example, say there are 3 possible solutions and we call them
                |             solution1, solution2 and solution3. Call this code the first time and
                |             InsertIntoComponentWithInfo will use solution1. Call this code the second time
                |             (provided that CntrTgt remains the same) and solution2 will be used. The third
                |             time, solution3. The fourth time, solution1 and so one.
                |             
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCompatible
                |          Dim dbVar1(2) As CATSafeArrayVariant
                |          Dim objArg2 As AnyObject
                |          Dim objArg3 As AnyObject
                |          Dim bVar4 As boolean
                |           ...
                |          objThisIntf.GetBestFitInsertInfodbVar1,objArg2,objArg3,bVar4

        :param tuple i_db2_placement_pt:
        :param AnyObject i_insert_compat_info:
        :param AnyObject io_insert_info:
        :param bool i_b_yes_cycle_all_solns:
        :rtype: tuple
        """
        return self.sch_compatible.GetBestFitInsertInfo(
            i_db2_placement_pt,
            i_insert_compat_info.com_object,
            io_insert_info.com_object,
            i_b_yes_cycle_all_solns
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_best_fit_insert_info'
        # # vba_code = """
        # # Public Function get_best_fit_insert_info(sch_compatible)
        # #     Dim iDb2PlacementPt (2)
        # #     sch_compatible.GetBestFitInsertInfo iDb2PlacementPt
        # #     get_best_fit_insert_info = iDb2PlacementPt
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_best_fit_place_info(
            self,
            i_db2_placement_pt: tuple,
            i_place_compat_info: AnyObject,
            io_place_info: AnyObject,
            i_b_yes_cycle_all_solns: bool
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetBestFitPlaceInfo(CATSafeArrayVariant
                | iDb2PlacementPt,
                | AnyObject iPlaceCompatInfo,
                | AnyObject ioPlaceInfo,
                | boolean iBYesCycleAllSolns)
                | 
                |     Find the best-fit connector(s) to be used for placing a component and
                |     connecting it to another.
                | 
                |     Parameters:
                | 
                |         iDb2PlacementPt
                |             X-Y coordinates of the target component graphical selection point.
                |             
                |         iPlaceCompatInfo
                |             Pointer to an internal class which contains structured information
                |             This is an output of IsTargetOKForPlace 
                |         ioPlaceInfo
                |             Pointer to an internal class which contains structured information
                |             for how to place a component. Caller must initialize this pointer to NULL when
                |             calling this code the first time. This is used as an input to
                |             CATISchComponent::PlaceOnComponentWithInfo 
                |         iBYesCycleAllSolns
                |             default is FALSE, and ioPlaceInfo is an output for the best fit
                |             solution. This solution will connect the compatible Target connector closest to
                |             the iDb2PlacementPt (call this CntrTgt) and the source connector that is
                |             closest to the origin (in position relative to ditto axis). If
                |             iBYesCycleAllSolns =TRUE, then the implementation will calculate all possible
                |             solutions and allow the caller to recall this code with the same ioPlaceInfo,
                |             if and only if the compatible Target connector closest to the iDb2PlacementPt
                |             is the same as the previous one . By doing this, this code will set the
                |             internal data ioPlaceInfo accordingly, so that when used in
                |             PlaceOnComponentWithInfo, the next solution will be used. For example, say
                |             there are 3 possible solutions and we call them solution1, solution2 and
                |             solution3. Call this code the first time and PlaceOnComponentWithInfo will use
                |             solution1. Call this code the second time (provided that CntrTgt remains the
                |             same) and solution2 will be used. The third time, solution3. The fourth time,
                |             solution1 and so one. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCompatible
                |          Dim dbVar1(2) As CATSafeArrayVariant
                |          Dim objArg2 As AnyObject
                |          Dim objArg3 As AnyObject
                |          Dim bVar4 As boolean
                |           ...
                |          objThisIntf.GetBestFitPlaceInfodbVar1,objArg2,objArg3,bVar4

        :param tuple i_db2_placement_pt:
        :param AnyObject i_place_compat_info:
        :param AnyObject io_place_info:
        :param bool i_b_yes_cycle_all_solns:
        :rtype: tuple
        """
        return self.sch_compatible.GetBestFitPlaceInfo(
            i_db2_placement_pt,
            i_place_compat_info.com_object,
            io_place_info.com_object,
            i_b_yes_cycle_all_solns
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_best_fit_place_info'
        # # vba_code = """
        # # Public Function get_best_fit_place_info(sch_compatible)
        # #     Dim iDb2PlacementPt (2)
        # #     sch_compatible.GetBestFitPlaceInfo iDb2PlacementPt
        # #     get_best_fit_place_info = iDb2PlacementPt
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_target_ok_for_insert(
            self,
            i_comp_info: AnyObject,
            o_insert_compat_info: AnyObject,
            o_b_yes: bool
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsTargetOKForInsert(AnyObject iCompInfo,
                | AnyObject oInsertCompatInfo,
                | boolean oBYes)
                | 
                |     Query whether an object is compatible to be inserted into a route This
                |     method is used when placing a component.
                | 
                |     Parameters:
                | 
                |         iCompInfo
                |             Pointer to an internal class which contains structured information
                |             of "this" component for placement. This is an output of
                |             CATISchComponent::QueryPlaceAbility 
                |         oInsertCompatInfo
                |             Pointer to an internal class which contains structured information
                |             for "this" component and target route (the one in question) This is used as an
                |             input to GetBestFitInsertInfo 
                |         oBYes
                |             If TRUE, the component is OK to be connected to a route.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchCompatible
                |          Dim objArg1 As AnyObject
                |          Dim objArg2 As AnyObject
                |          Dim bVar3 As boolean
                |           ...
                |          objThisIntf.IsTargetOKForInsertobjArg1,objArg2,bVar3

        :param AnyObject i_comp_info:
        :param AnyObject o_insert_compat_info:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_compatible.IsTargetOKForInsert(i_comp_info.com_object, o_insert_compat_info.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_target_ok_for_insert'
        # # vba_code = """
        # # Public Function is_target_ok_for_insert(sch_compatible)
        # #     Dim iCompInfo (2)
        # #     sch_compatible.IsTargetOKForInsert iCompInfo
        # #     is_target_ok_for_insert = iCompInfo
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_target_ok_for_place(
            self,
            i_grr_target: SchGRRComp,
            i_comp_info: AnyObject,
            o_place_compat_info: AnyObject,
            o_b_yes: bool
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsTargetOKForPlace(SchGRRComp iGRRTarget,
                | AnyObject iCompInfo,
                | AnyObject oPlaceCompatInfo,
                | boolean oBYes)
                | 
                |     Query whether an object is compatible to be connected to another component
                |     This method is used when placing a component.
                | 
                |     Parameters:
                | 
                |         iGRRTarget
                |             Pointer to the graphical image of the component in question (the
                |             target component to be connected to) 
                |         iCompInfo
                |             Pointer to an internal class which contains structured information
                |             of "this" component for placement. This is an output of
                |             CATISchComponent::QueryPlaceAbility 
                |         oPlaceCompatInfo
                |             Pointer to an internal class which contains structured information
                |             for "this" component and target component (the one in question) This is used as
                |             an input to GetBestFitPlaceInfo 
                |         oBYes
                |             If TRUE, the component is OK to be connected to a route.
                |             
                |     Example:
                |
                |          Dim objThisIntf As SchCompatible
                |          Dim objArg1 As SchGRRComp
                |          Dim objArg2 As AnyObject
                |          Dim objArg3 As AnyObject
                |          Dim bVar4 As boolean
                |           ...
                |          objThisIntf.IsTargetOKForPlaceobjArg1,objArg2,objArg3,bVar4

        :param SchGRRComp i_grr_target:
        :param AnyObject i_comp_info:
        :param AnyObject o_place_compat_info:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_compatible.IsTargetOKForPlace(
            i_grr_target.com_object,
            i_comp_info.com_object,
            o_place_compat_info.com_object,
            o_b_yes
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_target_ok_for_place'
        # # vba_code = """
        # # Public Function is_target_ok_for_place(sch_compatible)
        # #     Dim iGRRTarget (2)
        # #     sch_compatible.IsTargetOKForPlace iGRRTarget
        # #     is_target_ok_for_place = iGRRTarget
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_target_ok_for_route(
            self,
            i_route_cntr_class_type: str,
            i_grr_target: SchGRR,
            o_lok_cntrs: SchListOfObjects,
            o_b_yes: bool
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsTargetOKForRoute(CATBSTR iRouteCntrClassType,
                | SchGRR iGRRTarget,
                | SchListOfObjects oLOKCntrs,
                | boolean oBYes)
                | 
                |     Query whether an object is compatible to be connected to a route. This
                |     method is used when routing a route.
                | 
                |     Parameters:
                | 
                |         iRouteCntrClassType
                |             Class type of a schematic route connector. 
                |         iGRRTarget
                |             Pointer to the graphical image of a target component or to the
                |             primitive of a target route 
                |         oLOKCntrs
                |             A list of compatible and available connectors on the component or
                |             route (members are CATISchAppConnector interface pointers) This is used as an
                |             input to GetBestCntrForRoute 
                |         oBYes
                |             If TRUE, the component is OK to be connected to a route.
                |
                |     Example:
                |          Dim objThisIntf As SchCompatible
                |          Dim strVar1 As String
                |          Dim objArg2 As SchGRR
                |          Dim objArg3 As SchListOfObjects
                |          Dim bVar4 As boolean
                |           ...
                |          objThisIntf.IsTargetOKForRoutestrVar1,objArg2,objArg3,bVar4

        :param str i_route_cntr_class_type:
        :param SchGRR i_grr_target:
        :param SchListOfObjects o_lok_cntrs:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_compatible.IsTargetOKForRoute(
            i_route_cntr_class_type,
            i_grr_target.com_object,
            o_lok_cntrs.com_object,
            o_b_yes
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_target_ok_for_route'
        # # vba_code = """
        # # Public Function is_target_ok_for_route(sch_compatible)
        # #     Dim iRouteCntrClassType (2)
        # #     sch_compatible.IsTargetOKForRoute iRouteCntrClassType
        # #     is_target_ok_for_route = iRouteCntrClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchCompatible(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class CompositeTolerance(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CompositeTolerance
                | 
                | Interface for accessing composite tolerance on a TPS.
                | (ASME norm only)
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.composite_tolerance = com_object

    @property
    def box_count(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BoxCount() As double (Read Only)
                | 
                |     Retrieves datum count.

        :rtype: float
        """

        return self.composite_tolerance.BoxCount

    @property
    def value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Value() As double (Read Only)
                | 
                |     Retrieves value (in millimeters).
                | 
                |     Parameters:
                | 
                |         oValue
                |             Positive or equal to -1 which means not valuated.

        :rtype: float
        """

        return self.composite_tolerance.Value

    def __repr__(self):
        return f'CompositeTolerance(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeScaling(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeScaling
                | 
                | Represents the hybrid shape scaling feature object.
                | Role: To access the data of the hybrid shape feature object. This data
                | includes:
                | 
                |     The element to be transformed using the scaling
                |     The reference element for the scaling which is a point or a
                |     plane
                |     The ratio and its value
                | 
                | Use the CATIAHybridShapeFactory to create HybridShapeFeature
                | object.
                | 
                | LICENSING INFORMATION: Creation of volume result requires GSO
                | License
                | if GSO License is not granted , setting of Volume context has not
                | effect
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_scaling = com_object

    @property
    def center(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Center() As Reference
                | 
                |     Returns or sets the reference element.This element can be a point or a
                |     plane.
                |     Sub-element(s) supported (see Boundary object): PlanarFace or
                |     Vertex.
                | 
                |     Example:
                |         This example retrieves in RefElem the reference element for the Scaling
                |         hybrid shape feature.
                | 
                |          Dim RefElem As Reference
                |          Set RefElem = Scaling.Center

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_scaling.Center)

    @center.setter
    def center(self, reference_center: Reference):
        """
        :param Reference reference_center:
        """

        self.hybrid_shape_scaling.Center = reference_center.com_object

    @property
    def creation_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CreationMode() As boolean
                | 
                |     Returns or sets the creation mode(creation or
                |     modification).
                |     Legal values: True if the result is a creation feature and False if the
                |     result is a modification feature.
                | 
                |     Example:
                | 
                |           This example sets that the mode of
                |          the hybShpScaling hybrid shape scaling to creation
                |          
                | 
                |          hybShpScaling.CreationMode = True

        :rtype: bool
        """

        return self.hybrid_shape_scaling.CreationMode

    @creation_mode.setter
    def creation_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_scaling.CreationMode = value

    @property
    def elem_to_scale(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ElemToScale() As Reference
                | 
                |     Returns or sets the element to scale.
                | 
                |     Example:
                |         This example retrieves in Elem the element to scale for the Scaling
                |         hybrid shape feature.
                | 
                |          Dim Elem As Reference
                |          Set Elem = Scaling.ElemToScale

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_scaling.ElemToScale)

    @elem_to_scale.setter
    def elem_to_scale(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_scaling.ElemToScale = reference_element.com_object

    @property
    def ratio(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Ratio() As RealParam (Read Only)
                | 
                |     Returns the scaling ratio.

        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_scaling.Ratio)

    @property
    def ratio_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RatioValue() As double
                | 
                |     Returns or sets the scaling ratio value.
                | 
                |     Example:
                |         This example retrieves in Value the ratio value for the Scaling hybrid
                |         shape feature.
                | 
                |          Dim Value As double
                |          Set Value = Scaling.RatioValue

        :rtype: float
        """

        return self.hybrid_shape_scaling.RatioValue

    @ratio_value.setter
    def ratio_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_scaling.RatioValue = value

    @property
    def volume_result(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property VolumeResult() As boolean
                | 
                |     Returns or sets the volume result.
                |     Legal values: True if the result of Scaling is required as volume (option
                |     is effective only in case of volumes,requires GSO License) and False if it is
                |     needed as surface .
                | 
                |     Example:
                | 
                |           This example sets that the result of
                |          the hybShpScaling hybrid shape scaling is volume.
                |          
                | 
                |          hybShpScaling.VolumeResult = True

        :rtype: bool
        """

        return self.hybrid_shape_scaling.VolumeResult

    @volume_result.setter
    def volume_result(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_scaling.VolumeResult = value

    def __repr__(self):
        return f'HybridShapeScaling(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_solution_step_images import ABQSolutionStepImages
from pycatia.analysis_interfaces.analysis_image import AnalysisImage
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class ABQSolutionStep(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQSolutionStep
                | 
                | Represents an Abaqus solution step (ABQSolutionStep) object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_solution_step = com_object

    @property
    def analysis_images(self) -> ABQSolutionStepImages:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisImages() As ABQSolutionStepImages (Read
                | Only)
                | 
                |     Returns the analysis images associated with this solution
                |     step.
                | 
                |     Returns:
                |         The collection of analysis images. 
                |     Example:
                |         The following example retrieves the analysis images collection
                |         AnalysisImages in ListSolutionStepImages.
                | 
                |          Dim MySolutionStep As ABQSolutionStep
                |          Dim ListSolutionStepImages As ABQSolutionStepImages
                |          Set ListSolutionStepImages = MySolutionStep.AnalysisImages

        :rtype: ABQSolutionStepImages
        """

        return ABQSolutionStepImages(self.abq_solution_step.AnalysisImages)

    def create_image(
            self,
            i_image_name: str,
            i_hide_existing_images: cat_variant,
            i_incr_or_mode_number: cat_variant) -> AnalysisImage:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateImage(CATBSTR iImageName,
                | CATVariant iHideExistingImages,
                | CATVariant iIncrOrModeNumber) As AnalysisImage
                | 
                |     Creates a new image under this solution step.
                | 
                |     Parameters:
                | 
                |         iImageName
                |             The name of the image to create. 
                |         iHideExistingImages
                |             To deactivate or not all the activated images before create the new
                |             image. 
                |         iIncrOrModeNumber
                |             Increment or mode (for frequency step) number to be set in created
                |             image. 
                | 
                |     Returns:
                |         The created Analysis Image 
                |     Example:
                | 
                |           This example create ThisAnalysisImage in the MySolutionStep.
                |           
                | 
                |          The image to create is supposed to be a mesh deformed image for first
                |          increment. 
                | 
                |          
                | 
                |          Dim MySolutionStep As ABQSolutionStep
                |          Dim ThisAnalysisImage As AnalysisImage
                |          Set ThisAnalysisImage = MySolutionStep.CreateImage("Mesh_Deformed", True, 1)

        :param str i_image_name:
        :param cat_variant i_hide_existing_images:
        :param cat_variant i_incr_or_mode_number:
        :rtype: AnalysisImage
        """
        return AnalysisImage(
            self.abq_solution_step.CreateImage(
                i_image_name,
                i_hide_existing_images,
                i_incr_or_mode_number
            )
        )

    def set_increment_or_mode_number(
            self,
            i_incr_or_mode_number: cat_variant,
            i_image: AnalysisImage) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetIncrementOrModeNumber(CATVariant iIncrOrModeNumber,
                | AnalysisImage iImage)
                | 
                |     Sets increment number for an image.
                |     This is done related to an existing image
                | 
                |     Parameters:
                | 
                |         iIncrOrModeNumber
                |             The increment or mode (for frequency step) number to
                |             select

        :param cat_variant i_incr_or_mode_number:
        :param AnalysisImage i_image:
        :rtype: None
        """
        return self.abq_solution_step.SetIncrementOrModeNumber(
            i_incr_or_mode_number,
            i_image.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_increment_or_mode_number'
        # # vba_code = """
        # # Public Function set_increment_or_mode_number(abq_solution_step)
        # #     Dim iIncrOrModeNumber (2)
        # #     abq_solution_step.SetIncrementOrModeNumber iIncrOrModeNumber
        # #     set_increment_or_mode_number = iIncrOrModeNumber
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQSolutionStep(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_load import ABQLoad


class ABQPressure(ABQLoad):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQLoad
                |                         ABQPressure
                | 
                | Represents an Abaqus pressure (ABQPressure) object.
                | Role: Access an Abaqus pressure object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_pressure = com_object

    @property
    def apply_user_subroutine(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ApplyUserSubroutine() As boolean
                | 
                |     Sets or returns the user subroutine flag.
                | 
                |     Returns:
                |         A boolean specifying whether a user subroutine will be applied.

        :rtype: bool
        """

        return self.abq_pressure.ApplyUserSubroutine

    @apply_user_subroutine.setter
    def apply_user_subroutine(self, value: bool):
        """
        :param bool value:
        """

        self.abq_pressure.ApplyUserSubroutine = value

    @property
    def magnitude(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Magnitude() As double
                | 
                |     Sets or returns the magnitude of the pressure load.
                | 
                |     Returns:
                |         The magnitude of the pressure load.

        :rtype: float
        """

        return self.abq_pressure.Magnitude

    @magnitude.setter
    def magnitude(self, value: float):
        """
        :param float value:
        """

        self.abq_pressure.Magnitude = value

    def __repr__(self):
        return f'ABQPressure(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_connection_parameters import SFMConnectionParameters
from pycatia.cat_str_functional_interfaces.sfm_slot import SFMSlot
from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class SFMSlots(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     SfmSlots
                | 
                | Interface to create, remove and access existing slot.
                | Role: Allows creating,removing and accessing slot object.
                | 
                | See also:
                |     SfmSlots, SfmSuperPlate, SfmProfile, SfmConnectionParameters
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=SFMSlot)
        self.sfm_slots = com_object

    def add_slot(
            self,
            i_penetrated_element: Reference,
            i_penetrating_object: Reference,
            i_slot_name: str,
            i_list_parameters: SFMConnectionParameters
    ) -> SFMSlot:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddSlot(Reference iPenetratedElement,
                | Reference iPenetratingObject,
                | CATBSTR iSlotName,
                | SfmConnectionParameters iListParameters) As SfmSlot
                | 
                |     Creates a New Slot.
                | 
                |     Parameters:
                | 
                |         iPenetratedElement
                |             [in] Object on which slot will be created(Plate/Profile).
                |             
                |         iPenetratingObject
                |             [in] Object using which slot will be created(Profile).
                |             
                |         iSlotName
                |             [in] Slot Name. 
                |         iListParameters
                |             [in] List of UDF parameters. 
                |         oSfmSlot
                |             [out] Created Slot. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example creates a new Slot on Plate.
                | 
                |              Dim PenetratedRef, PenetratingRef As Reference
                |              Set PenetratedRef = PartObj.CreateReferenceFromObject(SfmSuperPlateObj)
                |              Set PenetratingRef = PartObj.CreateReferenceFromObject(SfmSuperStiffenerObj)
                |              Dim SlotFactory As SfmOperationFactory
                |              Set SlotFactory = PartObj.GetCustomerFactory("SfmOperationFactory")
                |              Dim oListSlotParams As SfmConnectionParameters
                |              Dim oListSlotPramNames() As Variant
                |              SlotFactory.GetSlotParameters SfmSuperStiffenerObj,
                |              "Tee_Slot_thru_Plate", oListSlotParams,
                |              oListSlotPramNames
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim NewSlot As SfmSlot
                |              Set NewSlot = SlotsonPlate.AddSlot(PenetratedRef, PenetratedRef, "Tee_Slot_thru_Plate", oListSlotParams, oListSlotPramNames)

        :param Reference i_penetrated_element:
        :param Reference i_penetrating_object:
        :param str i_slot_name:
        :param SFMConnectionParameters i_list_parameters:
        :rtype: SFMSlot
        """
        return SFMSlot(
            self.sfm_slots.AddSlot(
                i_penetrated_element.com_object,
                i_penetrating_object.com_object,
                i_slot_name,
                i_list_parameters.com_object
            )
        )

    def item(self, i_index: cat_variant) -> SFMSlot:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As SfmSlot
                | 
                |     Gets existing Slot.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             [in] Index of the Slot to be retrieved. 
                |         oSfmSlot
                |             [out] The retrieved slot. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example gets existing slot on a Plate.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim CntSlotsOnPlate As Long
                |              CntSlotsOnPlate = SlotsonPlate.Count
                |              Dim SlotObj As SfmSlot
                |              For i = 1 To CntSlotsOnPlate
                |              Set SlotObj = SlotsonPlate.Item(i)
                |              Next

        :param cat_variant i_index:
        :rtype: SFMSlot
        """
        return SFMSlot(self.sfm_slots.Item(i_index))

    def remove_slot(self, i_sfm_slot: SFMSlot) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveSlot(SfmSlot iSfmSlot)
                | 
                |     Removes Existing Slot.
                | 
                |     Parameters:
                | 
                |         iSfmSlot
                |             [in] Slot to be removed. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example removes existing slot on a Plate.
                | 
                |              Dim SlotsonPlate As SfmSlots
                |              Set SlotsonPlate = SfmSuperPlateObj.GetSlotsOnPlate
                |              Dim SlotObj As SfmSlot
                |              Set SlotObj = SlotsonPlate.Item(1)
                |              SlotsonPlate.RemoveSlot(SlotObj)

        :param SFMSlot i_sfm_slot:
        :rtype: None
        """
        return self.sfm_slots.RemoveSlot(i_sfm_slot.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_slot'
        # # vba_code = """
        # # Public Function remove_slot(sfm_slots)
        # #     Dim iSfmSlot (2)
        # #     sfm_slots.RemoveSlot iSfmSlot
        # #     remove_slot = iSfmSlot
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SFMSlots(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class FasReportingSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         FASReportingSettingAtt
                | 
                | The interface to access a DNBIAFASReportingSettingAtt.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.fas_reporting_setting_att = com_object

    @property
    def default_style_sheet(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DefaultStyleSheet() As CATBSTR
                | 
                |     Gets value of "OLP Robot Program Directory" parameter.
                |     Role: Gets value of "OLP Robot Program Directory"
                |     parameter
                | 
                |     Parameters:
                | 
                |         oRobotProgramDir
                |             Variable to return value in. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :rtype: str
        """

        return self.fas_reporting_setting_att.DefaultStyleSheet

    @default_style_sheet.setter
    def default_style_sheet(self, value: str):
        """
        :param str value:
        """

        self.fas_reporting_setting_att.DefaultStyleSheet = value

    @property
    def java_class_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property JavaClassPath() As CATBSTR
                | 
                |     Gets value of "Java Class Path" parameter.
                |     Role: Gets value of "Java Class Path" parameter
                | 
                |     Parameters:
                | 
                |         o
                |             JavaClassPath Variable to return value in. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :rtype: str
        """

        return self.fas_reporting_setting_att.JavaClassPath

    @java_class_path.setter
    def java_class_path(self, value: str):
        """
        :param str value:
        """

        self.fas_reporting_setting_att.JavaClassPath = value

    @property
    def java_exe(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property JavaExe() As CATBSTR
                | 
                |     Gets value of "Java Executable" parameter.
                |     Role: Gets value of "Java Executable" parameter
                | 
                |     Parameters:
                | 
                |         oJavaExe
                |             Variable to return value in. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :rtype: str
        """

        return self.fas_reporting_setting_att.JavaExe

    @java_exe.setter
    def java_exe(self, value: str):
        """
        :param str value:
        """

        self.fas_reporting_setting_att.JavaExe = value

    @property
    def result_output_dir(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ResultOutputDir() As CATBSTR
                | 
                |     Gets value of "OLP Robot Program Directory" parameter.
                |     Role: Gets value of "OLP Robot Program Directory"
                |     parameter
                | 
                |     Parameters:
                | 
                |         oRobotProgramDir
                |             Variable to return value in. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :rtype: str
        """

        return self.fas_reporting_setting_att.ResultOutputDir

    @result_output_dir.setter
    def result_output_dir(self, value: str):
        """
        :param str value:
        """

        self.fas_reporting_setting_att.ResultOutputDir = value

    @property
    def svg_viewer(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SVGViewer() As long
                | 
                |     Gets value of "OLP Robot Program Directory" parameter.
                |     Role: Gets value of "OLP Robot Program Directory"
                |     parameter
                | 
                |     Parameters:
                | 
                |         oRobotProgramDir
                |             Variable to return value in. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :rtype: int
        """

        return self.fas_reporting_setting_att.SVGViewer

    @svg_viewer.setter
    def svg_viewer(self, value: int):
        """
        :param int value:
        """

        self.fas_reporting_setting_att.SVGViewer = value

    @property
    def style_sheet_dir(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StyleSheetDir() As CATBSTR
                | 
                |     Gets value of "OLP Robot Program Directory" parameter.
                |     Role: Gets value of "OLP Robot Program Directory"
                |     parameter
                | 
                |     Parameters:
                | 
                |         oRobotProgramDir
                |             Variable to return value in. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :rtype: str
        """

        return self.fas_reporting_setting_att.StyleSheetDir

    @style_sheet_dir.setter
    def style_sheet_dir(self, value: str):
        """
        :param str value:
        """

        self.fas_reporting_setting_att.StyleSheetDir = value

    def get_default_style_sheet_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDefaultStyleSheetInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Gets information on "OLP Robot Program Directory"
                |     parameter.
                |     Role: Gets information on "OLP Robot Program Directory"
                |     parameter
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value. Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fas_reporting_setting_att.GetDefaultStyleSheetInfo(io_admin_level, io_locked)

    def get_java_class_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetJavaClassPathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Gets information on "Java Class Path" parameter.
                |     Role: Gets information on "Java Class Path" parameter
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value. Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fas_reporting_setting_att.GetJavaClassPathInfo(io_admin_level, io_locked)

    def get_java_exe_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetJavaExeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Gets information on "Java Executable" parameter.
                |     Role: Gets information on "Java Executable" parameter
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value. Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fas_reporting_setting_att.GetJavaExeInfo(io_admin_level, io_locked)

    def get_result_output_dir_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetResultOutputDirInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Gets information on "OLP Robot Program Directory"
                |     parameter.
                |     Role: Gets information on "OLP Robot Program Directory"
                |     parameter
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value. Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fas_reporting_setting_att.GetResultOutputDirInfo(io_admin_level, io_locked)

    def get_svg_viewer_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSVGViewerInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Gets information on "OLP Robot Program Directory"
                |     parameter.
                |     Role: Gets information on "OLP Robot Program Directory"
                |     parameter
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value. Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fas_reporting_setting_att.GetSVGViewerInfo(io_admin_level, io_locked)

    def get_style_sheet_dir_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStyleSheetDirInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Gets information on "OLP Robot Program Directory"
                |     parameter.
                |     Role: Gets information on "OLP Robot Program Directory"
                |     parameter
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value. Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.fas_reporting_setting_att.GetStyleSheetDirInfo(io_admin_level, io_locked)

    def set_default_style_sheet_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDefaultStyleSheetLock(boolean iLocked)
                | 
                |     Locks or unlocks the "OLP Robot Program Directory"
                |     parameter.
                |     Role: Locks or unlocks the "OLP Robot Program Directory" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fas_reporting_setting_att.SetDefaultStyleSheetLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_style_sheet_lock'
        # # vba_code = """
        # # Public Function set_default_style_sheet_lock(fas_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     fas_reporting_setting_att.SetDefaultStyleSheetLock iLocked
        # #     set_default_style_sheet_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_java_class_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetJavaClassPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Java Class Path" parameter.
                |     Role: Locks or unlocks the "Java Class Path" parameter if the operation is
                |     allowed in the current administrated environment. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fas_reporting_setting_att.SetJavaClassPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_java_class_path_lock'
        # # vba_code = """
        # # Public Function set_java_class_path_lock(fas_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     fas_reporting_setting_att.SetJavaClassPathLock iLocked
        # #     set_java_class_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_java_exe_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetJavaExeLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Java Executable" parameter.
                |     Role: Locks or unlocks the "Java Executable" parameter if the operation is
                |     allowed in the current administrated environment. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fas_reporting_setting_att.SetJavaExeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_java_exe_lock'
        # # vba_code = """
        # # Public Function set_java_exe_lock(fas_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     fas_reporting_setting_att.SetJavaExeLock iLocked
        # #     set_java_exe_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_result_output_dir_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetResultOutputDirLock(boolean iLocked)
                | 
                |     Locks or unlocks the "OLP Robot Program Directory"
                |     parameter.
                |     Role: Locks or unlocks the "OLP Robot Program Directory" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fas_reporting_setting_att.SetResultOutputDirLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_result_output_dir_lock'
        # # vba_code = """
        # # Public Function set_result_output_dir_lock(fas_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     fas_reporting_setting_att.SetResultOutputDirLock iLocked
        # #     set_result_output_dir_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_svg_viewer_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSVGViewerLock(boolean iLocked)
                | 
                |     Locks or unlocks the "OLP Robot Program Directory"
                |     parameter.
                |     Role: Locks or unlocks the "OLP Robot Program Directory" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fas_reporting_setting_att.SetSVGViewerLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_svg_viewer_lock'
        # # vba_code = """
        # # Public Function set_svg_viewer_lock(fas_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     fas_reporting_setting_att.SetSVGViewerLock iLocked
        # #     set_svg_viewer_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_style_sheet_dir_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStyleSheetDirLock(boolean iLocked)
                | 
                |     Locks or unlocks the "OLP Robot Program Directory"
                |     parameter.
                |     Role: Locks or unlocks the "OLP Robot Program Directory" parameter if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on Failure

        :param bool i_locked:
        :rtype: None
        """
        return self.fas_reporting_setting_att.SetStyleSheetDirLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_style_sheet_dir_lock'
        # # vba_code = """
        # # Public Function set_style_sheet_dir_lock(fas_reporting_setting_att)
        # #     Dim iLocked (2)
        # #     fas_reporting_setting_att.SetStyleSheetDirLock iLocked
        # #     set_style_sheet_dir_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'FasReportingSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.document import Document
from pycatia.in_interfaces.workbench import Workbench
from pycatia.system_interfaces.any_object import AnyObject


class PCBWorkbench(Workbench):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         PCBWorkbench
                | 
                | Interface to access Circuit Board Design workbench object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pcb_workbench = com_object

    def create_board(self, i_root: AnyObject) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateBoard(CATBaseDispatch iRoot) As CATBaseDispatch
                | 
                |     Allows to create a Board.
                | 
                |     Parameters:
                | 
                |         iRoot
                |             Root product of the Part to extend 
                |         oBoard
                |             The board created 
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :param AnyObject i_root:
        :rtype: AnyObject
        """
        return self.pcb_workbench.CreateBoard(i_root.com_object)

    def create_component(
            self,
            i_root: AnyObject,
            i_elec_package_number: str,
            i_elec_part_number: str,
            i_elec_type: str
    ) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateComponent(CATBaseDispatch iRoot,
                | CATBSTR iElecPackageNumber,
                | CATBSTR iElecPartNumber,
                | CATBSTR iElecType) As CATBaseDispatch
                | 
                |     Allows to create a Component.
                | 
                |     Parameters:
                | 
                |         iRoot
                |             Root product of the Part to extend 
                |         iElecPackageNumber
                |             The package number used to valuate the component attribute
                |             
                |         iElecPartNumber
                |             The part number used to valuate the part number of the component
                |             
                |         iElecType
                |             The Type of the component to create : ELECTRICAL or MECHANICAL 
                |         oComponent
                |             The Component created 
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :param AnyObject i_root:
        :param str i_elec_package_number:
        :param str i_elec_part_number:
        :param str i_elec_type:
        :rtype: AnyObject
        """
        return self.pcb_workbench.CreateComponent(
            i_root.com_object,
            i_elec_package_number,
            i_elec_part_number,
            i_elec_type
        )

    def create_panel(self, i_root: AnyObject) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreatePanel(CATBaseDispatch iRoot) As CATBaseDispatch
                | 
                |     Allows to create a panel.
                | 
                |     Parameters:
                | 
                |         iRoot
                |             Root product of the Part to extend 
                |         oPanel
                |             The panel created 
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :param AnyObject i_root:
        :rtype: AnyObject
        """
        return self.pcb_workbench.CreatePanel(i_root.com_object)

    def get_root_product(self, doc: Document) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRootProduct(Document doc) As CATBaseDispatch
                | 
                |     Allows to get the root product of a document.
                | 
                |     Parameters:
                | 
                |         doc
                |             The document to scan 
                |         oRoot
                |             The root product of the document scanned 
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :param Document doc:
        :rtype: AnyObject
        """
        return self.pcb_workbench.GetRootProduct(doc.com_object)

    def __repr__(self):
        return f'PCBWorkbench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_load import ABQLoad
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQLoads(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQLoads
                | 
                | The collection of Abaqus load (ABQLoad) objects attached to an
                | ABQGeneralStaticStep, ABQHeatTransferStep, or an ABQExplicitDynamicsStep
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQLoad)
        self.abq_loads = com_object

    def add(self, i_load_type: str) -> ABQLoad:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iLoadType) As ABQLoad
                | 
                |     Creates a new Abaqus load and adds it to the collection of Abaqus
                |     loads.
                | 
                |     Parameters:
                | 
                |         iLoadType
                |             The type of the load to create.
                | 
                |             Legal values:
                | 
                |             "ABQPressure"
                |             "ABQConcentratedForce"
                |             "ABQGravity"
                |             "ABQFilmCondition"
                | 
                |     Returns:
                |         oLoad The Abaqus load object that was created. 
                |     Example:
                |         The following example creates a pressure load in the ABQLoads
                |         collection:
                | 
                |          Dim abaqusLoads As ABQLoads
                |          Dim abqPressure As ABQPressure
                |          Set abaqusLoads = generalstaticstep.Loads
                |          Set abqPressure =  abaqusLoads.Add("ABQPressure")

        :param str i_load_type:
        :rtype: ABQLoad
        """
        return ABQLoad(self.abq_loads.Add(i_load_type))

    def item(self, i_index: cat_variant) -> ABQLoad:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQLoad
                | 
                |     Returns an Abaqus load using its index or its name from the ABQLoads
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus load to retrieve from the
                |             collection of Abaqus loads. If the index is a number, it specifies the rank of
                |             the Abaqus load in the collection. The index of the first Abaqus load in the
                |             collection is 1, and the index of the last load is Count. If the index is a
                |             string, it specifies the name you assigned to the load using the
                |             CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQLoad.

        :param cat_variant i_index:
        :rtype: ABQLoad
        """
        return ABQLoad(self.abq_loads.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a Abaqus load using its index or its name from the collection od
                |     loads.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus load n to retrieve from the
                |             collection of Abaqus loads. If the index is a number, it specifies the rank of
                |             the Abaqus load in the collection. The index of the first Abaqus load in the
                |             collection is 1, and the index of the last load is Count. If the index is a
                |             string, it specifies the name you assigned to the load using the
                |             CATIACollection::Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_loads.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_loads)
        # #     Dim iIndex (2)
        # #     abq_loads.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQLoads(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_route import SchAppRoute
from pycatia.system_interfaces.any_object import AnyObject


class SchAppObjectFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppObjectFactory
                | 
                | Application factory to create application objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_object_factory = com_object

    def app_create_comp_ref(self, i_app_comp_class_type: str, o_app_comp: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateCompRef(CATBSTR iAppCompClassType,
                | AnyObject oAppComp)
                | 
                |     Create an Application Component reference.
                | 
                |     Parameters:
                | 
                |         iAppCompClassType
                |             Class type of the Application Component reference.
                |             
                |         oAppComp
                |             The new Application Component object created (CATISchAppComponent
                |             interface pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory
                |          Dim strVar1 As String
                |          Dim objArg2 As AnyObject
                |           ...
                |          objThisIntf.AppCreateCompRefstrVar1,objArg2

        :param str i_app_comp_class_type:
        :param AnyObject o_app_comp:
        :rtype: None
        """
        return self.sch_app_object_factory.AppCreateCompRef(i_app_comp_class_type, o_app_comp.com_object)

    def app_create_connection(self, i_app_cntn_class_type: str, o_app_connection: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateConnection(CATBSTR iAppCntnClassType,
                | AnyObject oAppConnection)
                | 
                |     Create an Application Connection object.
                | 
                |     Parameters:
                | 
                |         iAppCntnClassType
                |             Class type of the Application Connection object. 
                |         oAppConnection
                |             The new Application Connection object created (CATISchAppConnection
                |             interface pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory
                |          Dim strVar1 As String
                |          Dim objArg2 As AnyObject
                |           ...
                |          objThisIntf.AppCreateConnectionstrVar1,objArg2

        :param str i_app_cntn_class_type:
        :param AnyObject o_app_connection:
        :rtype: None
        """
        return self.sch_app_object_factory.AppCreateConnection(i_app_cntn_class_type, o_app_connection.com_object)

    def app_create_group(self, i_app_group_class_type: str, o_app_group: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateGroup(CATBSTR iAppGroupClassType,
                | AnyObject oAppGroup)
                | 
                |     Create an Application Group object.
                | 
                |     Parameters:
                | 
                |         iAppGroupClassType
                |             Class type of the Application Group object. 
                |         oAppGroup
                |             The new Application Group object created (CATISchAppGroup interface
                |             pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory
                |          Dim strVar1 As String
                |          Dim objArg2 As AnyObject
                |           ...
                |          objThisIntf.AppCreateGroupstrVar1,objArg2

        :param str i_app_group_class_type:
        :param AnyObject o_app_group:
        :rtype: None
        """
        return self.sch_app_object_factory.AppCreateGroup(i_app_group_class_type, o_app_group.com_object)

    def app_create_route(self, i_app_route_class_type: str, o_app_route: AnyObject, i_log_line_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateRoute(CATBSTR iAppRouteClassType,
                | AnyObject oAppRoute,
                | CATBSTR iLogLineID)
                | 
                |     Create an Application Route object.
                | 
                |     Parameters:
                | 
                |         iAppRouteClassType
                |             Class type of the Application Route object. 
                |         oAppRoute
                |             The new Application Route object created (CATISchAppRoute interface
                |             pointer). 
                |         iLogLineID
                |             The logical line ID that will contain the new route. This is an
                |             optional input. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory
                |          Dim strVar1 As String
                |          Dim objArg2 As AnyObject
                |          Dim strVar3 As String
                |           ...
                |          objThisIntf.AppCreateRoutestrVar1,objArg2,strVar3

        :param str i_app_route_class_type:
        :param AnyObject o_app_route:
        :param str i_log_line_id:
        :rtype: None
        """
        return self.sch_app_object_factory.AppCreateRoute(i_app_route_class_type, o_app_route.com_object, i_log_line_id)

    def app_create_route_from_ref(
            self,
            i_route_reference: SchAppRoute,
            o_app_route: AnyObject,
            i_log_line_id: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateRouteFromRef(SchAppRoute iRouteReference,
                | AnyObject oAppRoute,
                | CATBSTR iLogLineID)
                | 
                |     Create an Application Route object with a specific
                |     reference.
                | 
                |     Parameters:
                | 
                |         iAppRouteRef
                |             Route reference to creaet the output route from 
                |         oAppRoute
                |             The new Application Route object created (CATISchAppRoute interface
                |             pointer). 
                |         iLogLineID
                |             The logical line ID that will contain the new route. This is an
                |             optional input. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory
                |          Dim objArg1 As SchAppRoute
                |          Dim objArg2 As AnyObject
                |          Dim strVar3 As String
                |           ...
                |         objThisIntf.AppCreateRouteFromRefobjArg1,objArg2,strVar3

        :param SchAppRoute i_route_reference:
        :param AnyObject o_app_route:
        :param str i_log_line_id:
        :rtype: None
        """
        return self.sch_app_object_factory.AppCreateRouteFromRef(
            i_route_reference.com_object,
            o_app_route.com_object,
            i_log_line_id
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_create_route_from_ref'
        # # vba_code = """
        # # Public Function app_create_route_from_ref(sch_app_object_factory)
        # #     Dim iRouteReference (2)
        # #     sch_app_object_factory.AppCreateRouteFromRef iRouteReference
        # #     app_create_route_from_ref = iRouteReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_create_zone(self, i_app_zone_class_type: str, o_app_zone: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppCreateZone(CATBSTR iAppZoneClassType,
                | AnyObject oAppZone)
                | 
                |     Create an Application Zone object.
                | 
                |     Parameters:
                | 
                |         iAppZoneClassType
                |             Class type of the Application Zone object. 
                |         oAppZone
                |             The new Application Zone object created (CATISchAppZone interface
                |             pointer). 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppObjectFactory
                |          Dim strVar1 As String
                |          Dim objArg2 As AnyObject
                |           ...
                |          objThisIntf.AppCreateZonestrVar1,objArg2

        :param str i_app_zone_class_type:
        :param AnyObject o_app_zone:
        :rtype: None
        """
        return self.sch_app_object_factory.AppCreateZone(i_app_zone_class_type, o_app_zone.com_object)

    def __repr__(self):
        return f'SchAppObjectFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_boundary_condition import ABQBoundaryCondition
from pycatia.abq_automation_interfaces.abq_clamp_bc import ABQClampBC
from pycatia.abq_automation_interfaces.abq_displacement_bc import ABQDisplacementBC
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product


class ABQIAABQBaseMotionVB(ABQBoundaryCondition):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQBoundaryCondition
                |                         ABQIAABQBaseMotionVB
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement ABQIAABQBaseMotion are ...
                | 
                | Do not use the ABQIAABQBaseMotion interface for such and such ClassReference,
                | Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abqiaabq_base_motion_vb = com_object

    @property
    def base_motion_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BaseMotionType() As CATBSTR

        :rtype: str
        """

        return self.abqiaabq_base_motion_vb.BaseMotionType

    @base_motion_type.setter
    def base_motion_type(self, value: str):
        """
        :param str value:
        """

        self.abqiaabq_base_motion_vb.BaseMotionType = value

    @property
    def base_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BaseType() As short

        :rtype: int
        """

        return self.abqiaabq_base_motion_vb.BaseType

    @base_type.setter
    def base_type(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_base_motion_vb.BaseType = value

    @property
    def clamp_support(self) -> ABQClampBC:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ClampSupport() As ABQClampBC

        :rtype: ABQClampBC
        """

        return ABQClampBC(self.abqiaabq_base_motion_vb.ClampSupport)

    @clamp_support.setter
    def clamp_support(self, value: ABQClampBC):
        """
        :param ABQClampBC value:
        """

        self.abqiaabq_base_motion_vb.ClampSupport = value

    @property
    def dof(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DOF() As double

        :rtype: float
        """

        return self.abqiaabq_base_motion_vb.DOF

    @dof.setter
    def dof(self, value: float):
        """
        :param float value:
        """

        self.abqiaabq_base_motion_vb.DOF = value

    @property
    def data_type(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DataType() As boolean

        :rtype: bool
        """

        return self.abqiaabq_base_motion_vb.DataType

    @data_type.setter
    def data_type(self, value: bool):
        """
        :param bool value:
        """

        self.abqiaabq_base_motion_vb.DataType = value

    @property
    def disp_bc_support(self) -> ABQDisplacementBC:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DispBCSupport() As ABQDisplacementBC

        :rtype: ABQDisplacementBC
        """

        return ABQDisplacementBC(self.abqiaabq_base_motion_vb.DispBCSupport)

    @disp_bc_support.setter
    def disp_bc_support(self, value: ABQDisplacementBC):
        """
        :param ABQDisplacementBC value:
        """

        self.abqiaabq_base_motion_vb.DispBCSupport = value

    @property
    def frequency_data_values(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FrequencyDataValues(CATSafeArrayVariant iFreqDataVal) (Write
                | Only)

        :rtype: int
        """

        return self.abqiaabq_base_motion_vb.FrequencyDataValues

    @frequency_data_values.setter
    def frequency_data_values(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_base_motion_vb.FrequencyDataValues = value

    @property
    def imaginary_data_values(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImaginaryDataValues(CATSafeArrayVariant iImaginaryDataValues)
                | (Write Only)

        :rtype: False
        """

        return self.abqiaabq_base_motion_vb.ImaginaryDataValues

    @imaginary_data_values.setter
    def imaginary_data_values(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_base_motion_vb.ImaginaryDataValues = value

    @property
    def real_data_values(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RealDataValues(CATSafeArrayVariant iRealDataVal) (Write
                | Only)

        :rtype: False
        """

        return self.abqiaabq_base_motion_vb.RealDataValues

    @real_data_values.setter
    def real_data_values(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_base_motion_vb.RealDataValues = value

    @property
    def scale(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Scale() As double

        :rtype: float
        """

        return self.abqiaabq_base_motion_vb.Scale

    @scale.setter
    def scale(self, value: float):
        """
        :param float value:
        """

        self.abqiaabq_base_motion_vb.Scale = value

    def add_centre_of_rotation(self, i_product: Product, i_ref: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddCentreOfRotation(Product iProduct,
                | Reference iRef)

        :param Product i_product:
        :param Reference i_ref:
        :rtype: None
        """
        return self.abqiaabq_base_motion_vb.AddCentreOfRotation(i_product.com_object, i_ref.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_centre_of_rotation'
        # # vba_code = """
        # # Public Function add_centre_of_rotation(abqiaabq_base_motion_vb)
        # #     Dim iProduct (2)
        # #     abqiaabq_base_motion_vb.AddCentreOfRotation iProduct
        # #     add_centre_of_rotation = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQIAABQBaseMotionVB(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_welds import SFMWelds
from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject


class SFMSplitPlate(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmSplitPlate
                | 
                | Interface to manage the Structure Functional Modeler Split plate
                | object.
                | Role: Provides access to weld objects on Split plate.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_split_plate = com_object

    def get_welds(self, i_operating_ele: Reference) -> SFMWelds:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWelds(Reference iOperatingEle) As SfmWelds
                | 
                |     Gets Welds feature on operated Plate.
                | 
                |     Parameters:
                | 
                |         iOperatingEle
                |             [in] Operating element of the weld features. 
                |         oWelds
                |             [out] The retrieved Weld features. 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This example gets welds features of Split Plate.
                | 
                |              Dim Welds As SfmWelds
                |              Set Welds = Split_Plate.GetWelds(Nothing)

        :param Reference i_operating_ele:
        :rtype: SFMWelds
        """
        return SFMWelds(self.sfm_split_plate.GetWelds(i_operating_ele.com_object))

    def __repr__(self):
        return f'SFMSplitPlate(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class Line(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         Line
                | 
                | Represents the hybrid shape Line feature object.
                | Role: Declare hybrid shape Line root feature object. All interfaces for
                | different type of Line derives HybridShapeLine.
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeLine
                | objects.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.line = com_object

    @property
    def first_upto_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstUptoElem() As Reference
                | 
                |     Role: Gets the First upto element of the line.
                | 
                |     Parameters:
                | 
                |         oFirstUpto
                | 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else

        :rtype: Reference
        """

        return Reference(self.line.FirstUptoElem)

    @first_upto_elem.setter
    def first_upto_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.line.FirstUptoElem = reference_element.com_object

    @property
    def second_upto_elem(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondUptoElem() As Reference
                | 
                |     Role: Gets the Second upto element of the line.
                | 
                |     Parameters:
                | 
                |         oSecondUpto
                | 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else

        :rtype: Reference
        """

        return Reference(self.line.SecondUptoElem)

    @second_upto_elem.setter
    def second_upto_elem(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.line.SecondUptoElem = reference_element.com_object

    def get_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDirection(CATSafeArrayVariant oDirection)
                | 
                |     Role: Returns the unit-vector pointing in the direction of the
                |     line.
                | 
                |     Parameters:
                | 
                |         oDirection
                |         oDirection[0]
                |             The X Coordinate of the unit vector pointing in the direction of
                |             the line 
                |         oDirection[1]
                |             The Y Coordinate of the unit vector pointing in the direction of
                |             the line 
                |         oDirection[2]
                |             The Z Coordinate of the unit vector pointing in the direction of
                |             the line 
                | 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: None
        """
        vba_function_name = "get_direction"
        vba_code = """
        Public Function get_direction(line)
            Dim oDirection (2)
            line.GetDirection oDirection
            get_direction = oDirection
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self, o_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Role: Returns the origin of the line.
                | 
                |     Parameters:
                | 
                |         oOrigin
                |         oOrigin[0]
                |             The X Coordinate of a point lying on the line 
                |         oOrigin[1]
                |             The Y Coordinate of a point lying on the line 
                |         oOrigin[2]
                |             The Z Coordinate of a point lying on the line The Origin is
                |             evaluated from the geometry of the line. 
                | 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :param tuple o_origin:
        :rtype: None
        """
        return self.line.GetOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(line)
        # #     Dim oOrigin (2)
        # #     line.GetOrigin oOrigin
        # #     get_origin = oOrigin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_direction(self, i_direction: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutDirection(CATSafeArrayVariant iDirection)
                | 
                |     Role: Sets the unit-vector pointing in the direction of the
                |     line.
                | 
                |     Parameters:
                | 
                |         iDirection
                |         iDirection[0]
                |             The X Coordinate of the unit vector pointing in the direction of
                |             the line 
                |         iDirection[1]
                |             The Y Coordinate of the unit vector pointing in the direction of
                |             the line 
                |         iDirection[2]
                |             The Z Coordinate of the unit vector pointing in the direction of
                |             the line 
                | 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :param tuple i_direction:
        :rtype: None
        """
        return self.line.PutDirection(i_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_direction'
        # # vba_code = """
        # # Public Function put_direction(line)
        # #     Dim iDirection (2)
        # #     line.PutDirection iDirection
        # #     put_direction = iDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Line(name="{self.name}")'
